@@ -279,9 +279,9 @@ class StreamApp(object):
         self.actor.args = params
         # TODO get_set_param,get_set_runtime_param
         input_ports = self.get_actor_input_ports(actor_json)
-        print("input_ports>>>>" + json.dumps(input_ports))
+        print("input_ports>>>>" + str(input_ports))
         output_ports = self.get_actor_output_ports(actor_json)
-        print("output_ports>>>>" + json.dumps(output_ports))
+        print("output_ports>>>>" + str(output_ports))
         self.actor.set_input_ports(input_ports)
         self.actor.set_output_ports(output_ports)
         # 设置actor状态为已开始
